# QUBE

        .+-------+
      .' :     .'|        QUBE | Quantitative Backtesting Environment
     +-------+'  |             | (Community version) 
     |   : * |   |        
     |  ,+---|---+ 
     |.'     | .' 
     +-------+'

Community version of Quantitative Backtesting Framework for development trading strategies. It provides tools to backtest, optimize, 
and analyze trading strategies using historical data. Library includes various functions that help with signal generation, portfolio construction, 
performance analysis, risk management, and plotting. 

Qube can be used to build automated trading systems for different financial markets like stocks, futures, forex, cryptocurrencies, and indices. It is compatible with Jupyter notebooks, IPython, or plain Python scripts. 


# Installation
```pip install git+https://git@github.com/dmarienko/Qube.git```

# Using 
See docs folder:
- [Simple strategy example](https://github.com/dmarienko/Qube/blob/main/docs/1.0%20Signal%20Generators.ipynb)
-    [Optimization example](https://github.com/dmarienko/Qube/blob/main/docs/2.0%20Backtesting%20with%20optimizations.ipynb)
